@@ -9,8 +9,7 @@
 predict_quantile.model_fit <-
   function(object, new_data, quantile = (1:9)/10, ...) {
 
-    if (is.null(object$spec$method$pred$quantile))
-      rlang::abort("No quantile prediction method defined for this engine.")
+    check_spec_pred_type(object, "quantile")
 
     if (inherits(object$fit, "try-error")) {
       rlang::warn("Model fit failed; cannot make predictions.")
